@@ -7,12 +7,14 @@ from typing import Hashable
 from typing import List
 from typing import Optional
 from typing import Tuple
+from typing import Union
 
 import numpy as np
 import pandas as pd
 
 from art import tprint
 from lmfit import Minimizer
+from lmfit import Parameter
 from lmfit import Parameters
 from lmfit import conf_interval
 from lmfit import report_ci
@@ -151,7 +153,7 @@ class RegressionMetrics:
                 try:
                     metric_dict[fnc.__name__].append(fnc(y_true, y_pred))
                 except ValueError as err:
-                    print(f"ValueError: {err} for {fnc.__name__}!")
+                    print(f"## Warning: {err} for {fnc.__name__}!")
                     metric_dict[fnc.__name__].append(np.nan)
         return pd.DataFrame(metric_dict).T.to_dict(orient="split")
 
@@ -199,19 +201,13 @@ def fit_report_as_dict(
     )
     for name in parnames:
         par = params[name]
-        buffer["variables"][name] = {}
+        buffer["variables"][name] = {"init_value": get_init_value(param=par)}
 
-        if par.init_value is not None:
-            buffer["variables"][name]["init_value"] = par.init_value
-        elif par.expr is not None:
-            buffer["variables"][name]["init_value"] = f"As expressed value: {par.expr}"
-        else:
-            buffer["variables"][name]["init_value"] = f"As fixed value: {par.value}"
         if modelpars is not None and name in modelpars:
             buffer["variables"][name]["model_value"] = modelpars[name].value
         try:
             buffer["variables"][name]["best_value"] = par.value
-        except (TypeError, ValueError):
+        except (TypeError, ValueError):  # pragma: no cover
             buffer["variables"][name]["init_value"] = "NonNumericValue"
         if par.stderr is not None:
             buffer["variables"][name]["error_relative"] = par.stderr
@@ -219,7 +215,7 @@ def fit_report_as_dict(
                 buffer["variables"][name]["error_absolute"] = (
                     abs(par.stderr / par.value) * 100
                 )
-            except ZeroDivisionError:
+            except ZeroDivisionError:  # pragma: no cover
                 buffer["variables"][name]["error_absolute"] = np.inf
 
     for i, name_1 in enumerate(parnames):
@@ -244,6 +240,27 @@ def fit_report_as_dict(
     return buffer
 
 
+def get_init_value(
+    param: Parameter, modelpars: Optional[Parameter] = None
+) -> Union[float, str]:
+    """Get the initial value of a parameter.
+
+    Args:
+        param (Parameter): The Parameter to extract the initial value from.
+        modelpars (Parameter, optional): Known Model Parameters. Defaults to None.
+
+    Returns:
+        Union[float, str]: The initial value.
+    """
+    if param.init_value is not None:
+        return param.init_value
+    if param.expr is not None:
+        return f"As expressed value: {param.expr}"
+    if modelpars is not None and param.name in modelpars:
+        return modelpars[param.name].value
+    return f"As fixed value: {param.value}"
+
+
 def _extracted_gof_from_results(
     result: minimize, buffer: Dict[str, Any], params: Parameters
 ) -> Tuple[minimize, Dict[str, Any], Parameters]:
@@ -316,9 +333,9 @@ class PrintingResults:
     def __call__(self) -> None:
         """Print the results of the fitting process."""
         if self.args["verbose"] == 1:
-            self.printing_verbose_mode
+            self.printing_verbose_mode()
         elif self.args["verbose"] == 2:
-            self.printing_regular_mode
+            self.printing_regular_mode()
 
     @staticmethod
     def print_tabulate(args: Dict[str, Any]) -> None:
@@ -336,7 +353,6 @@ class PrintingResults:
             )
         )
 
-    @property
     def printing_regular_mode(self) -> None:
         """Print the fitting results in the regular mode."""
         self.print_statistic()
@@ -367,7 +383,7 @@ class PrintingResults:
                         self.minimizer, self.result, **self.args["conf_interval"]
                     )
                 )
-            except (MinimizerException, ValueError) as exc:
+            except (MinimizerException, ValueError, KeyError, TypeError) as exc:
                 print(f"Error: {exc} -> No confidence interval could be calculated!")
                 self.args["confidence_interval"] = {}
 
@@ -381,7 +397,6 @@ class PrintingResults:
         print("\nRegression Metrics:\n")
         self.print_tabulate(args=self.args["regression_metrics"])
 
-    @property
     def printing_verbose_mode(self) -> None:
         """Print all results in verbose mode."""
         self.print_statistic_verbose()
@@ -426,37 +441,30 @@ class PrintingResults:
 class PrintingStatus:
     """Print the status of the fitting process."""
 
-    @property
     def welcome(self) -> None:
         """Print the welcome message."""
         tprint("SpectraFit", font="3-d")
 
-    @property
     def version(self) -> None:
         """Print current version of the SpectraFit."""
         print(f"Currently used version is: {__version__}")
 
-    @property
     def start(self) -> None:
         """Print the start of the fitting process."""
         print("\nStart of the fitting process:\n")
 
-    @property
     def end(self) -> None:
         """Print the end of the fitting process."""
         print("\nEnd of the fitting process:\n")
 
-    @property
     def thanks(self) -> None:
         """Print the end of the fitting process."""
         print("\nThanks for using SpectraFit!")
 
-    @property
     def yes_no(self) -> None:
         """Print the end of the fitting process."""
         print("\nDo you want to continue? (y/n)")
 
-    @property
     def credits(self) -> None:
         """Print the credits of the fitting process."""
         tprint("\nCredits:\n", font="3-d")
