@@ -1,5 +1,7 @@
 """Collection of essential tools for running SpectraFit."""
+import gzip
 import json
+import pickle
 import sys
 
 from pathlib import Path
@@ -204,13 +206,13 @@ class PostProcessing:
 
     def __call__(self) -> Tuple[pd.DataFrame, Dict[str, Any]]:
         """Call the post-processing."""
-        self.make_insight_report
-        self.make_residual_fit
-        self.make_fit_contributions
-        self.export_correlation2args
-        self.export_results2args
-        self.export_regression_metrics2args
-        self.export_desprective_statistic2args
+        self.make_insight_report()
+        self.make_residual_fit()
+        self.make_fit_contributions()
+        self.export_correlation2args()
+        self.export_results2args()
+        self.export_regression_metrics2args()
+        self.export_desprective_statistic2args()
         return (self.df, self.args)
 
     def check_global_fitting(self) -> Optional[int]:
@@ -263,7 +265,6 @@ class PostProcessing:
             }
         )
 
-    @property
     def make_insight_report(self) -> None:
         """Make an insight-report of the fit statistic.
 
@@ -290,11 +291,10 @@ class PostProcessing:
                 self.args["confidence_interval"] = conf_interval(
                     self.minimizer, self.result, **self.args["conf_interval"]
                 )
-            except (MinimizerException, ValueError) as exc:
+            except (MinimizerException, ValueError, KeyError) as exc:
                 print(f"Error: {exc} -> No confidence interval could be calculated!")
                 self.args["confidence_interval"] = {}
 
-    @property
     def make_residual_fit(self) -> None:
         r"""Make the residuals of the model and the fit.
 
@@ -336,7 +336,6 @@ class PostProcessing:
             )
         self.df = df_copy
 
-    @property
     def make_fit_contributions(self) -> None:
         """Make the fit contributions of the best fit model.
 
@@ -350,7 +349,6 @@ class PostProcessing:
             global_fit=self.args["global_"],
         )
 
-    @property
     def export_correlation2args(self) -> None:
         """Export the correlation matrix to the input file arguments.
 
@@ -381,12 +379,10 @@ class PostProcessing:
         """
         self.args["linear_correlation"] = self.df.corr().to_dict(orient="split")
 
-    @property
     def export_results2args(self) -> None:
         """Export the results of the fit to the input file arguments."""
         self.args["fit_result"] = self.df.to_dict(orient="split")
 
-    @property
     def export_regression_metrics2args(self) -> None:
         """Export the regression metrics of the fit to the input file arguments.
 
@@ -396,7 +392,6 @@ class PostProcessing:
         """
         self.args["regression_metrics"] = RegressionMetrics(self.df)()
 
-    @property
     def export_desprective_statistic2args(self) -> None:
         """Export the descriptive statistic of the spectra, fit, and contributions."""
         self.args["descriptive_statistic"] = self.df.describe(
@@ -472,10 +467,9 @@ class SaveResult:
 
     def __call__(self) -> None:
         """Call the SaveResult class."""
-        self.save_as_json
-        self.save_as_csv
+        self.save_as_json()
+        self.save_as_csv()
 
-    @property
     def save_as_csv(self) -> None:
         """Save the the fit results to csv files.
 
@@ -499,12 +493,11 @@ class SaveResult:
             index_label="attributes",
         )
 
-    @property
     def save_as_json(self) -> None:
         """Save the fitting result as json file."""
         if self.args["outfile"]:
             with open(
-                Path(f"{self.args['outfile']}_summary.json"), "w", encoding="utf8"
+                Path(f"{self.args['outfile']}_summary.json"), "w", encoding="utf-8"
             ) as f:
                 json.dump(self.args, f, indent=4)
         else:
@@ -533,10 +526,10 @@ def read_input_file(fname: Path) -> MutableMapping[str, Any]:
         with open(fname, "rb") as f:
             args = tomli.load(f)
     elif fname.suffix == ".json":
-        with open(fname, encoding="utf8") as f:
+        with open(fname, encoding="utf-8") as f:
             args = json.load(f)
     elif fname.suffix in [".yaml", ".yml"]:
-        with open(fname, encoding="utf8") as f:
+        with open(fname, encoding="utf-8") as f:
             args = yaml.load(f, Loader=yaml.FullLoader)
     else:
         raise OSError(
@@ -608,3 +601,69 @@ def check_keywords_consistency(
     for key in check_args:
         if key not in ref_args.keys():
             raise KeyError(f"ERROR: The {key} is not parameter of the `cmd-input`!")
+
+
+def unicode_check(f: Any, encoding: str = "latin1") -> Any:
+    """Check if the pkl file is encoded in unicode.
+
+    Args:
+        f (Any): The pkl file to load.
+        encoding (str, optional): The encoding to use. Defaults to "latin1".
+
+    Returns:
+        Any: The pkl file, which can be a nested dictionary containing raw data,
+            metadata, and other information.
+    """
+    try:
+        data_dict = pickle.load(f)
+    except UnicodeDecodeError:  # pragma: no cover
+        data_dict = pickle.load(f, encoding=encoding)
+    return data_dict
+
+
+def pkl2any(pkl_fname: Path, encoding: str = "latin1") -> Any:
+    """Load a pkl file and return the data as a any type of data or object.
+
+    Args:
+        pkl_fname (Path): The pkl file to load.
+        encoding (str, optional): The encoding to use. Defaults to "latin1".
+
+    Raises:
+        ValueError: If the file format is not supported.
+
+    Returns:
+        Any: Data or objects, which can contain various data types supported by pickle.
+    """
+    if pkl_fname.suffix == ".gz":
+        with gzip.open(pkl_fname, "rb") as f:
+            return unicode_check(f, encoding=encoding)
+    elif pkl_fname.suffix == ".pkl":
+        with open(pkl_fname, "rb") as f:
+            return unicode_check(f, encoding=encoding)
+    else:
+        choices = [".pkl", ".pkl.gz"]
+        raise ValueError(
+            f"File format '{pkl_fname.suffix}' is not supported. "
+            f"Supported file formats are: {choices}"
+        )
+
+
+def pure_fname(fname: Path) -> Path:
+    """Return the filename without the suffix.
+
+    Pure filename without the suffix is implemented to avoid the problem with
+    multiple dots in the filename like `test.pkl.gz` or `test.tar.gz`.
+    The `stem` attribute of the `Path` class returns the filename without the
+    suffix, but it also removes only the last suffix. Hence, the `test.pkl.gz`
+    will be returned as `test.pkl` and not as `test`. This function returns
+    the filename without the suffix. It is implemented recursively to remove
+    all suffixes.
+
+    Args:
+        fname (Path): The filename to be processed.
+
+    Returns:
+        Path: The filename without the suffix.
+    """
+    _fname = fname.parent / fname.stem
+    return pure_fname(_fname) if _fname.suffix else _fname
